// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef INCIDENCEEDITOR_VERSION_H
#define INCIDENCEEDITOR_VERSION_H

#define INCIDENCEEDITOR_VERSION_STRING "6.7.0"
#define INCIDENCEEDITOR_VERSION_MAJOR 6
#define INCIDENCEEDITOR_VERSION_MINOR 7
#define INCIDENCEEDITOR_VERSION_PATCH 0
#define INCIDENCEEDITOR_VERSION ((6<<16)|(7<<8)|(0))

#endif
